# Drawable image

A package to convert images to different sizes for the development of Android applications.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install drimage.

```bash
pip install drimg
```

## Usage

convert one image
```bash
$ drimg file_name
```


Convert all images of the current directory
```bash
$ drimg -a
```

:exclamation: It is not possible to process relative paths at this time, and you must use these commands in the directory where the images are located.

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[MIT](https://choosealicense.com/licenses/mit/)